<?php
/**
 * Hypochondria functions and definitions
 *
 * @package Hypochondria
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'hypochondria_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function hypochondria_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Hypochondria, use a find and replace
	 * to change 'hypochondria' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'hypochondria', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'hypochondria' ),
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
}
endif; // hypochondria_setup
add_action( 'after_setup_theme', 'hypochondria_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function hypochondria_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'hypochondria' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'hypochondria_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function hypochondria_scripts() {
	// Genericons
	wp_enqueue_style( 'hypochondria-genericons', get_template_directory_uri() . '/inc/genericons/genericons.css' );
	
	// Main stylesheet
	wp_enqueue_style( 'hypochondria-style', get_stylesheet_uri() );
	
	// Google Fonts: PT Sans, PT Sans Narrow, PT Serif
	wp_enqueue_style( 'hypochondria-google-fonts', 'http://fonts.googleapis.com/css?family=PT+Sans|PT+Sans+Narrow|PT+Serif' );

	wp_enqueue_script( 'hypochondria-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'hypochondria-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'hypochondria_scripts' );

/**
 * Customize the masthead section
 */
function hypochondria_extra_options( $wp_customize ) {
	// Set up customizer section for accent color
	$wp_customize->add_section( 'hy_colors', array(
		'title'    => __( 'Color Scheme', 'hypochondria' ),
		'priority' => 35
	) );
	
	// Customize accent color
	$wp_customize->add_setting( 'hypochondria_theme_options[accent_color]', array(
		'default'           => '#444444',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'accent_color', array(
		'label'    => __( 'Accent Color', 'hypochondria' ),
		'section'  => 'hy_colors',
		'settings' => 'hypochondria_theme_options[accent_color]'
	) ) );
	
	// Customize accent text color
	$wp_customize->add_setting( 'hypochondria_theme_options[accent_text_color]', array(
		'default'           => '#F8F8F8',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_hex_color'
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'accent_text_color', array(
		'label'    => __( 'Text Color', 'hypochondria' ),
		'section'  => 'hy_colors',
		'settings' => 'hypochondria_theme_options[accent_text_color]'
	) ) );
	
	// Display excerpts or not
	$wp_customize->add_section( 'hy_excerpts', array(
		'title'       => __( 'Excerpt Display Options', 'hypochondria' ),
		'description' => __( 'Controls whether full posts or excerpts should be displayed', 'hypochondria' ),
		'priority'    => 40
	) );
	
	// Home page
	$wp_customize->add_setting( 'hypochondria_theme_options[home_excerpts]', array(
		'default'    => 'full',
		'type'       => 'option',
		'capability' => 'edit_theme_options'
	) );
	
	$wp_customize->add_control( 'hypochondria_theme_options[home_excerpts]', array(
		'type'    => 'radio',
		'label'   => __( 'Home Page', 'hypochondria' ),
		'section' => 'hy_excerpts',
		'choices' => array(
			'full'    => __( 'Full Posts', 'hypochondria' ),
			'excerpt' => __( 'Excerpts', 'hypochondria' )
		)
	) );
	
	// Search results
	$wp_customize->add_setting( 'hypochondria_theme_options[search_excerpts]', array(
		'default'    => 'excerpt',
		'type'       => 'option',
		'capability' => 'edit_theme_options'
	) );
	
	$wp_customize->add_control( 'hypochondria_theme_options[search_excerpts]', array(
		'type'    => 'radio',
		'label'   => __( 'Search Results', 'hypochondria' ),
		'section' => 'hy_excerpts',
		'choices' => array(
			'full'    => __( 'Full Posts', 'hypochondria' ),
			'excerpt' => __( 'Excerpts', 'hypochondria' )
		)
	) );
	
	// Archives
	$wp_customize->add_setting( 'hypochondria_theme_options[archive_excerpts]', array(
		'default'    => 'excerpt',
		'type'       => 'option',
		'capability' => 'edit_theme_options'
	) );
	
	$wp_customize->add_control( 'hypochondria_theme_options[archive_excerpts]', array(
		'type'    => 'radio',
		'label'   => __( 'Archive Pages', 'hypochondria' ),
		'section' => 'hy_excerpts',
		'choices' => array(
			'full'    => __( 'Full Posts', 'hypochondria' ),
			'excerpt' => __( 'Excerpts', 'hypochondria' )
		)
	) );
}
add_action( 'customize_register', 'hypochondria_extra_options' );

function hypochondria_apply_branding() {
	// Get header colors...
	$options = get_option( 'hypochondria_theme_options' );
	$accent_color = $options[ 'accent_color' ];
	$accent_text_color = $options[ 'accent_text_color' ];

	if ( ! $accent_color || ! $accent_text_color ) :
		// ...and bail out if the option hasn't been set
		return;
	else :
		// Echo <style> tags as appropriate
		printf( '<style text="text/css" media="screen"> ' );
	
		printf( ' body { background: %1$s; } ', $accent_color );
	
		printf( ' #masthead a, #masthead .site-description, #masthead .sub-menu:before, #colophon, #colophon a { color: %1$s; } ', $accent_text_color );
		
		printf( ' input, input:focus, textarea, textarea:focus, select { background: %1$s; color: %2$s; }', $accent_color, $accent_text_color );
	
		printf( ' ::-webkit-input-placeholder { color: %1$s; }', $accent_text_color );
		printf( ' ::-moz-input-placeholder { color: %1$s; }', $accent_text_color );
		printf( ' :-ms-input-placeholder { color: %1$s; }', $accent_text_color );
		printf( ' input:-moz-placeholder { color: %1$s; }', $accent_text_color );
		
		printf( ' .comment-list > li, .comment-list .children > li, .widget, .archive-header, .search-header { border-top: 3px solid %1$s; }', $accent_color );
		
		printf( ' blockquote { border-left: 3px solid %1$s; }', $accent_color );
		
		printf( ' .sticky-post:before { color: %1$s }', $accent_color );
		
		printf( ' </style> ' );
	endif;
}
add_action( 'wp_head', 'hypochondria_apply_branding' );

/**
 * Strip HTML tags, even for users/admins
 */
function hypochondria_strip_tags( $commentdata ) {
	$commentdata[ 'comment_content' ] = wp_kses_data( $commentdata[ 'comment_content' ] );
	
	return $commentdata;	
}
add_filter( 'preprocess_comment', 'hypochondria_strip_tags', 10, 1 );

/**
 * Make "read more" link to the post
 */
function hypochondria_excerpt_link( $more ) {
	return ' <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">[...]</a>';
}
add_filter( 'excerpt_more', 'hypochondria_excerpt_link' );

/**
 * Add author's first name to comment reply link
 * Thanks to Raam Dev
 * http://raamdev.com/2013/personalizing-the-wordpress-comment-reply-link/
 */
function hypochondria_comment_author_to_reply_link( $link, $args, $comment ) {
	$comment = get_comment( $comment );
 
	// If no comment author is blank, use 'Anonymous'
	if ( empty( $comment->comment_author ) ) :
        	if ( ! empty( $comment->user_id ) ) :
			$user = get_userdata( $comment->user_id );
			$author = $user->user_login;
		else :
			$author = __( 'Anonymous', 'hypochondria' );
		endif;
    else :
        $author = $comment->comment_author;
    endif;
 
    // If the user provided more than a first name, use only first name
    if ( strpos( $author, ' ' ) ) :
        $author = substr( $author, 0, strpos( $author, ' ' ) );
    endif;
 
    // Replace Reply Link with "Reply to (Author First Name)"
    $reply_link_text = $args[ 'reply_text' ];
    $link = str_replace( $reply_link_text, 'Reply to ' . $author, $link );
 
    return $link;
}
add_filter( 'comment_reply_link', 'hypochondria_comment_author_to_reply_link', 10, 3 );

/**
 * Implement custom editor styling
 */
function hypochondria_editor_styles() {
	add_editor_style( get_stylesheet_directory_uri() . '/inc/editor-style.css' );
}
add_action( 'init', 'hypochondria_editor_styles' );

/**
 * Implement the Custom Header feature.
 */
// require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';